==> ruby_r-1.6.8.2003.04.19.tgz: lib/ruby/1.6/alpha-freebsd4_r/rbconfig.rb <==

# This file was created by mkconfig.rb when ruby was built.  Any
# changes made to this file will be lost the next time ruby is built.

module Config
  RUBY_VERSION == "1.6.8" or
    raise "ruby lib version (1.6.8) doesn't match executable version (#{RUBY_VERSION})"

  DESTDIR = '' if not defined? DESTDIR
  CONFIG = {}
  TOPDIR = File.dirname(__FILE__).sub!(%r'/lib/ruby/1\.6/alpha\-freebsd4_r\Z', '')
  CONFIG["srcdir"] = "/tmp/a/ports/lang/ruby16_r/work/ruby-1.6.8"
  CONFIG["prefix"] = (TOPDIR || DESTDIR + "/usr/local")
  CONFIG["ruby_install_name"] = "ruby16_r"
  CONFIG["EXEEXT"] = ""
  CONFIG["SHELL"] = "/bin/sh"
  CONFIG["PATH_SEPARATOR"] = ":"
  CONFIG["PACKAGE_NAME"] = ""
  CONFIG["PACKAGE_TARNAME"] = ""
  CONFIG["PACKAGE_VERSION"] = ""
  CONFIG["PACKAGE_STRING"] = ""
  CONFIG["PACKAGE_BUGREPORT"] = ""
  CONFIG["exec_prefix"] = "$(prefix)"
  CONFIG["bindir"] = "$(exec_prefix)/bin"
  CONFIG["sbindir"] = "$(exec_prefix)/sbin"
  CONFIG["libexecdir"] = "$(exec_prefix)/libexec"
  CONFIG["datadir"] = "$(prefix)/share"
  CONFIG["sysconfdir"] = "$(prefix)/etc"
  CONFIG["sharedstatedir"] = "$(prefix)/com"
  CONFIG["localstatedir"] = "$(prefix)/var"
  CONFIG["libdir"] = "$(exec_prefix)/lib"
  CONFIG["includedir"] = "$(prefix)/include"
  CONFIG["oldincludedir"] = "/usr/include"
  CONFIG["infodir"] = "$(prefix)/info"
  CONFIG["mandir"] = "$(prefix)/man"
  CONFIG["build_alias"] = ""
  CONFIG["host_alias"] = ""
  CONFIG["target_alias"] = "alpha-freebsd4_r"
  CONFIG["ECHO_C"] = ""
  CONFIG["ECHO_N"] = "-n"
  CONFIG["ECHO_T"] = ""
  CONFIG["LIBS"] = "-lcrypt -lm"
  CONFIG["MAJOR"] = "1"
  CONFIG["MINOR"] = "6"
  CONFIG["TEENY"] = "8"
  CONFIG["build"] = "alpha-unknown-freebsd4.9"
  CONFIG["build_cpu"] = "alpha"
  CONFIG["build_vendor"] = "unknown"
  CONFIG["build_os"] = "freebsd4.9"
  CONFIG["host"] = "alpha-unknown-freebsd4.9"
  CONFIG["host_cpu"] = "alpha"
  CONFIG["host_vendor"] = "unknown"
  CONFIG["host_os"] = "freebsd4.9"
  CONFIG["target"] = "alpha-unknown-freebsd4_r"
  CONFIG["target_cpu"] = "alpha"
  CONFIG["target_vendor"] = "unknown"
  CONFIG["target_os"] = "freebsd4_r"
  CONFIG["CC"] = "cc"
  CONFIG["ac_ct_CC"] = "cc"
  CONFIG["CFLAGS"] = "-D_THREAD_SAFE -O -pipe -mcpu=ev4 -fPIC"
  CONFIG["LDFLAGS"] = "-rdynamic"
  CONFIG["CPPFLAGS"] = ""
  CONFIG["OBJEXT"] = "o"
  CONFIG["CPP"] = "cc -E"
  CONFIG["GNU_LD"] = "yes"
  CONFIG["CPPOUTFILE"] = "-o conftest.i"
  CONFIG["OUTFLAG"] = "-o"
  CONFIG["YACC"] = "byacc"
  CONFIG["RANLIB"] = "ranlib"
  CONFIG["ac_ct_RANLIB"] = "ranlib"
  CONFIG["AR"] = "ar"
  CONFIG["ac_ct_AR"] = "ar"
  CONFIG["NM"] = ""
  CONFIG["ac_ct_NM"] = ""
  CONFIG["DLLWRAP"] = ""
  CONFIG["ac_ct_DLLWRAP"] = ""
  CONFIG["AS"] = ""
  CONFIG["ac_ct_AS"] = ""
  CONFIG["DLLTOOL"] = ""
  CONFIG["ac_ct_DLLTOOL"] = ""
  CONFIG["WINDRES"] = ""
  CONFIG["ac_ct_WINDRES"] = ""
  CONFIG["LN_S"] = "ln -s"
  CONFIG["SET_MAKE"] = ""
  CONFIG["LIBOBJS"] = ""
  CONFIG["ALLOCA"] = ""
  CONFIG["XLDFLAGS"] = ""
  CONFIG["DLDFLAGS"] = "-Wl,-soname,$(.TARGET)"
  CONFIG["STATIC"] = ""
  CONFIG["CCDLFLAGS"] = "-fPIC"
  CONFIG["LDSHARED"] = "cc -shared"
  CONFIG["DLEXT"] = "so"
  CONFIG["DLEXT2"] = ""
  CONFIG["STRIP"] = "strip"
  CONFIG["EXTSTATIC"] = ""
  CONFIG["setup"] = "Setup"
  CONFIG["MINIRUBY"] = "./miniruby$(EXEEXT)"
  CONFIG["PREP"] = ""
  CONFIG["LIBRUBY_LDSHARED"] = "cc -shared"
  CONFIG["LIBRUBY_DLDFLAGS"] = "-Wl,-soname,$(.TARGET)"
  CONFIG["RUBY_INSTALL_NAME"] = "ruby16_r"
  CONFIG["RUBY_SO_NAME"] = ""
  CONFIG["LIBRUBY_A"] = "lib$(RUBY_INSTALL_NAME).a"
  CONFIG["LIBRUBY_SO"] = "lib$(RUBY_INSTALL_NAME).so.$(MAJOR)$(MINOR)"
  CONFIG["LIBRUBY_ALIASES"] = "lib$(RUBY_INSTALL_NAME).so"
  CONFIG["LIBRUBY"] = "$(LIBRUBY_SO)"
  CONFIG["LIBRUBYARG"] = "-L. -l$(RUBY_INSTALL_NAME)"
  CONFIG["SOLIBS"] = "$(LIBS)"
  CONFIG["DLDLIBS"] = "-lc"
  CONFIG["ENABLE_SHARED"] = "yes"
  CONFIG["MAINLIBS"] = "-pthread"
  CONFIG["arch"] = "alpha-freebsd4_r"
  CONFIG["sitedir"] = "$(prefix)/lib/ruby/site_ruby"
  CONFIG["configure_args"] = "'--target=alpha-freebsd4_r' '--program-prefix=' '--with-libc_r=yes' '--program-suffix=16_r' '--enable-shared' '--enable-ipv6' '--prefix=/usr/local' 'CFLAGS=-O -pipe -mcpu=ev4' 'target_alias=alpha-freebsd4_r' 'CC=cc'"
  CONFIG["NROFF"] = "/usr/bin/nroff"
  CONFIG["MANTYPE"] = "doc"
  CONFIG["abs_srcdir"] = "$(ac_abs_srcdir)"
  CONFIG["abs_top_srcdir"] = "$(ac_abs_top_srcdir)"
  CONFIG["builddir"] = "$(ac_builddir)"
  CONFIG["abs_builddir"] = "$(ac_abs_builddir)"
  CONFIG["top_builddir"] = "$(ac_top_builddir)"
  CONFIG["abs_top_builddir"] = "$(ac_abs_top_builddir)"
  CONFIG["ruby_version"] = "$(MAJOR).$(MINOR)"
  CONFIG["rubylibdir"] = "$(libdir)/ruby/$(ruby_version)"
  CONFIG["archdir"] = "$(rubylibdir)/$(arch)"
  CONFIG["sitelibdir"] = "$(sitedir)/$(ruby_version)"
  CONFIG["sitearchdir"] = "$(sitelibdir)/$(arch)"
  CONFIG["compile_dir"] = "/tmp/a/ports/lang/ruby16_r/work/ruby-1.6.8"
  MAKEFILE_CONFIG = {}
  CONFIG.each{|k,v| MAKEFILE_CONFIG[k] = v.dup}
  def Config::expand(val)
    val.gsub!(/\$\(([^()]+)\)/) do |var|
      key = $1
      if CONFIG.key? key
        Config::expand(CONFIG[key])
      else
	var
      end
    end
    val
  end
  CONFIG.each_value do |val|
    Config::expand(val)
  end
end

==> ruby_r-1.6.8.2004.07.28_1.tgz: lib/ruby/1.6/alpha-freebsd4_r/rbconfig.rb <==

# This file was created by mkconfig.rb when ruby was built.  Any
# changes made to this file will be lost the next time ruby is built.

module Config
  RUBY_VERSION == "1.6.8" or
    raise "ruby lib version (1.6.8) doesn't match executable version (#{RUBY_VERSION})"

  DESTDIR = '' if not defined? DESTDIR
  CONFIG = {}
  TOPDIR = File.dirname(__FILE__).sub!(%r'/lib/ruby/1\.6/alpha\-freebsd4_r\Z', '')
  CONFIG["srcdir"] = "/tmp/a/ports/lang/ruby16_r/work/ruby-1.6.8-2004.07.28"
  CONFIG["prefix"] = (TOPDIR || DESTDIR + "/usr/local")
  CONFIG["ruby_install_name"] = "ruby16_r"
  CONFIG["EXEEXT"] = ""
  CONFIG["SHELL"] = "/bin/sh"
  CONFIG["PATH_SEPARATOR"] = ":"
  CONFIG["PACKAGE_NAME"] = ""
  CONFIG["PACKAGE_TARNAME"] = ""
  CONFIG["PACKAGE_VERSION"] = ""
  CONFIG["PACKAGE_STRING"] = ""
  CONFIG["PACKAGE_BUGREPORT"] = ""
  CONFIG["exec_prefix"] = "$(prefix)"
  CONFIG["bindir"] = "$(exec_prefix)/bin"
  CONFIG["sbindir"] = "$(exec_prefix)/sbin"
  CONFIG["libexecdir"] = "$(exec_prefix)/libexec"
  CONFIG["datadir"] = "$(prefix)/share"
  CONFIG["sysconfdir"] = "$(prefix)/etc"
  CONFIG["sharedstatedir"] = "$(prefix)/com"
  CONFIG["localstatedir"] = "$(prefix)/var"
  CONFIG["libdir"] = "$(exec_prefix)/lib"
  CONFIG["includedir"] = "$(prefix)/include"
  CONFIG["oldincludedir"] = "/usr/include"
  CONFIG["infodir"] = "$(prefix)/info"
  CONFIG["mandir"] = "$(prefix)/man"
  CONFIG["build_alias"] = "alpha-portbld-freebsd4_r"
  CONFIG["host_alias"] = "alpha-portbld-freebsd4_r"
  CONFIG["target_alias"] = "alpha-portbld-freebsd4_r"
  CONFIG["ECHO_C"] = ""
  CONFIG["ECHO_N"] = "-n"
  CONFIG["ECHO_T"] = ""
  CONFIG["LIBS"] = "-lcrypt -lm"
  CONFIG["MAJOR"] = "1"
  CONFIG["MINOR"] = "6"
  CONFIG["TEENY"] = "8"
  CONFIG["build"] = "alpha-portbld-freebsd4_r"
  CONFIG["build_cpu"] = "alpha"
  CONFIG["build_vendor"] = "portbld"
  CONFIG["build_os"] = "freebsd4_r"
  CONFIG["host"] = "alpha-portbld-freebsd4_r"
  CONFIG["host_cpu"] = "alpha"
  CONFIG["host_vendor"] = "portbld"
  CONFIG["host_os"] = "freebsd4_r"
  CONFIG["target"] = "alpha-portbld-freebsd4_r"
  CONFIG["target_cpu"] = "alpha"
  CONFIG["target_vendor"] = "portbld"
  CONFIG["target_os"] = "freebsd4_r"
  CONFIG["CC"] = "cc"
  CONFIG["ac_ct_CC"] = ""
  CONFIG["CFLAGS"] = "-D_THREAD_SAFE -O -pipe -mcpu=ev4 -fPIC"
  CONFIG["LDFLAGS"] = "-rdynamic"
  CONFIG["CPPFLAGS"] = ""
  CONFIG["OBJEXT"] = "o"
  CONFIG["CPP"] = "cc -E"
  CONFIG["GNU_LD"] = "yes"
  CONFIG["CPPOUTFILE"] = "-o conftest.i"
  CONFIG["OUTFLAG"] = "-o"
  CONFIG["YACC"] = "byacc"
  CONFIG["RANLIB"] = "ranlib"
  CONFIG["ac_ct_RANLIB"] = "ranlib"
  CONFIG["AR"] = "ar"
  CONFIG["ac_ct_AR"] = "ar"
  CONFIG["NM"] = ""
  CONFIG["ac_ct_NM"] = ""
  CONFIG["DLLWRAP"] = ""
  CONFIG["ac_ct_DLLWRAP"] = ""
  CONFIG["AS"] = ""
  CONFIG["ac_ct_AS"] = ""
  CONFIG["DLLTOOL"] = ""
  CONFIG["ac_ct_DLLTOOL"] = ""
  CONFIG["WINDRES"] = ""
  CONFIG["ac_ct_WINDRES"] = ""
  CONFIG["LN_S"] = "ln -s"
  CONFIG["SET_MAKE"] = ""
  CONFIG["LIBOBJS"] = ""
  CONFIG["ALLOCA"] = ""
  CONFIG["XLDFLAGS"] = ""
  CONFIG["DLDFLAGS"] = "-Wl,-soname,$(.TARGET)"
  CONFIG["STATIC"] = ""
  CONFIG["CCDLFLAGS"] = "-fPIC"
  CONFIG["LDSHARED"] = "cc -shared"
  CONFIG["DLEXT"] = "so"
  CONFIG["DLEXT2"] = ""
  CONFIG["STRIP"] = "strip"
  CONFIG["EXTSTATIC"] = ""
  CONFIG["setup"] = "Setup"
  CONFIG["MINIRUBY"] = "./miniruby$(EXEEXT)"
  CONFIG["PREP"] = ""
  CONFIG["LIBRUBY_LDSHARED"] = "cc -shared"
  CONFIG["LIBRUBY_DLDFLAGS"] = "-Wl,-soname,$(.TARGET)"
  CONFIG["RUBY_INSTALL_NAME"] = "ruby16_r"
  CONFIG["RUBY_SO_NAME"] = ""
  CONFIG["LIBRUBY_A"] = "lib$(RUBY_INSTALL_NAME).a"
  CONFIG["LIBRUBY_SO"] = "lib$(RUBY_INSTALL_NAME).so.$(MAJOR)$(MINOR)"
  CONFIG["LIBRUBY_ALIASES"] = "lib$(RUBY_INSTALL_NAME).so"
  CONFIG["LIBRUBY"] = "$(LIBRUBY_SO)"
  CONFIG["LIBRUBYARG"] = "-L. -l$(RUBY_INSTALL_NAME)"
  CONFIG["SOLIBS"] = "$(LIBS)"
  CONFIG["DLDLIBS"] = "-lc"
  CONFIG["ENABLE_SHARED"] = "yes"
  CONFIG["MAINLIBS"] = "-pthread"
  CONFIG["arch"] = "alpha-freebsd4_r"
  CONFIG["sitedir"] = "$(prefix)/lib/ruby/site_ruby"
  CONFIG["configure_args"] = "'--program-prefix=' '--with-libc_r=yes' '--program-suffix=16_r' '--enable-shared' '--enable-ipv6' '--prefix=/usr/local' 'alpha-portbld-freebsd4_r' 'CFLAGS=-O -pipe -mcpu=ev4' 'host_alias=alpha-portbld-freebsd4_r' 'build_alias=alpha-portbld-freebsd4_r' 'target_alias=alpha-portbld-freebsd4_r' 'CC=cc'"
  CONFIG["NROFF"] = "/usr/bin/nroff"
  CONFIG["MANTYPE"] = "doc"
  CONFIG["abs_srcdir"] = "$(ac_abs_srcdir)"
  CONFIG["abs_top_srcdir"] = "$(ac_abs_top_srcdir)"
  CONFIG["builddir"] = "$(ac_builddir)"
  CONFIG["abs_builddir"] = "$(ac_abs_builddir)"
  CONFIG["top_builddir"] = "$(ac_top_builddir)"
  CONFIG["abs_top_builddir"] = "$(ac_abs_top_builddir)"
  CONFIG["ruby_version"] = "$(MAJOR).$(MINOR)"
  CONFIG["rubylibdir"] = "$(libdir)/ruby/$(ruby_version)"
  CONFIG["archdir"] = "$(rubylibdir)/$(arch)"
  CONFIG["sitelibdir"] = "$(sitedir)/$(ruby_version)"
  CONFIG["sitearchdir"] = "$(sitelibdir)/$(arch)"
  CONFIG["compile_dir"] = "/tmp/a/ports/lang/ruby16_r/work/ruby-1.6.8-2004.07.28"
  MAKEFILE_CONFIG = {}
  CONFIG.each{|k,v| MAKEFILE_CONFIG[k] = v.dup}
  def Config::expand(val)
    val.gsub!(/\$\(([^()]+)\)/) do |var|
      key = $1
      if CONFIG.key? key
        Config::expand(CONFIG[key])
      else
	var
      end
    end
    val
  end
  CONFIG.each_value do |val|
    Config::expand(val)
  end
end
